package com.example.qyfk;

import com.alibaba.fastjson.JSON;
import com.qiyukf.unicorn.api.ConsultSource;
import com.qiyukf.unicorn.api.StatusBarNotificationConfig;
import com.qiyukf.unicorn.api.Unicorn;
import com.qiyukf.unicorn.api.YSFOptions;
import com.qiyukf.unicorn.api.YSFUserInfo;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * QyfkPlugin
 */
public class QyfkPlugin implements MethodCallHandler {
    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "qyfk");
        channel.setMethodCallHandler(new QyfkPlugin());
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("init")) {
            _initSDK((ArrayList)call.arguments);
            result.success(null);
        } else if (call.method.equals("show")) {
            _show();
            result.success(null);
        } else if (call.method.equals("uploadCRM")) {
            _uploadCRM((ArrayList)call.arguments);
            result.success(null);
        } else if (call.method.equals("logout")) {
            _logout();
            result.success(null);
        } else {
            result.notImplemented();
        }
    }

    public void _initSDK(ArrayList arguments) {
        if (arguments.size() < 1) return;
        String appkey = (String) arguments.get(0);
        Unicorn.init(ContextHolder.getContext(), appkey, options(), new UILImageLoader());
    }

    public void _uploadCRM(ArrayList arguments) {
        if (arguments.size() < 3) return;

        String uid = (String)arguments.get(0);
        String name = (String)arguments.get(1);
        String phone = (String)arguments.get(2);

        YSFUserInfo userInfo = new YSFUserInfo();
        // App 的用户 ID
        userInfo.userId = uid;
        // 当且仅当开发者在管理后台开启了 authToken 校验功能时，该字段才有效
        // userInfo.authToken = "auth-token-from-user-server";

        Map<String,Object> nameMap = new HashMap<String,Object>();
        nameMap.put("key","real_name");
        nameMap.put("value",name);
        Map<String,Object> phoneMap = new HashMap<String,Object>();
        phoneMap.put("key","mobile_phone");
        phoneMap.put("value",phone);
        phoneMap.put("hidden",false);

        ArrayList list = new ArrayList();
        list.add(nameMap);
        list.add(phoneMap);
        String json=JSON.toJSONString(list);
        userInfo.data = json;
        Unicorn.setUserInfo(userInfo);
    }

    public void _logout() {
        Unicorn.logout();
    }

    public void _show() {
        String title = "在线客服";
        ConsultSource source = new ConsultSource("xiangjiao", title, "");
        Unicorn.openServiceActivity(ContextHolder.getContext(), title, source);
    }

    // 如果返回值为null，则全部使用默认参数。
    private YSFOptions options() {
        YSFOptions options = new YSFOptions();
        options.statusBarNotificationConfig = new StatusBarNotificationConfig();
        return options;
    }

}
