#import "QyfkPlugin.h"
#import "FlutterQYKF.h"
#import <QIYU_iOS_SDK/QYSDK.h>

@implementation QyfkPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"qyfk"
            binaryMessenger:[registrar messenger]];
  QyfkPlugin* instance = [[QyfkPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
    
    
  FLTQYKFFactory* webviewFactory =
  [[FLTQYKFFactory alloc] initWithMessenger:registrar.messenger];
  [registrar registerViewFactory:webviewFactory withId:@"qykf/qykf"];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"init" isEqualToString:call.method]) {
      [self initSDK:call.arguments];
      result(nil);
  } else if ([@"show" isEqualToString:call.method]) {
      [self show];
      result(nil);
  } else if ([@"uploadCRM" isEqualToString:call.method]) {
      [self uploadCRM:call.arguments];
      result(nil);
  } else if ([@"logout" isEqualToString:call.method]) {
      [self logout];
      result(nil);
  } else if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else {
    result(FlutterMethodNotImplemented);
  }
}

- (void)initSDK:(NSArray *)arguments {
    NSString *appKey = @"3858be3c20ceb6298575736cf27858a7";
    if ( [arguments count] > 0) {
        appKey = arguments[0];
    }
    NSString *appName= @"QYKF";
    if ( [arguments count] > 1) {
        appName= arguments[1];
    }
    [[QYSDK sharedSDK] registerAppId:appKey appName:appName];
}

- (void)uploadCRM:(NSArray *)arguments {
    if (arguments.count < 3) {
        return;
    }
    
    static NSString * const QYKey = @"key";
    static NSString * const QYValue = @"value";
    static NSString * const QYHidden = @"hidden";
    
    NSString *uid = arguments[0];
    NSString *name = arguments[1];
    NSString *phone = arguments[2];
    NSMutableArray *array = [NSMutableArray arrayWithCapacity:2];
    
    QYUserInfo *userInfo = [[QYUserInfo alloc] init];
    userInfo.userId = uid;
    
    if (name.length > 0) {
        NSDictionary *nameDict = @{
                                   QYKey : @"real_name",
                                   QYValue : name,
                                   };
        [array addObject:nameDict];
    }
    
    if (phone.length > 0) {
        NSDictionary *phoneDict = @{
                                    QYKey : @"mobile_phone",
                                    QYValue : phone,
                                    QYHidden : @(NO),
                                    };
        [array addObject:phoneDict];
    }
    
    
    NSData *data = [NSJSONSerialization dataWithJSONObject:array options:0 error:nil];
    if (data) {
        userInfo.data = [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
    }
    
    [[QYSDK sharedSDK] setUserInfo:userInfo];
}

- (void)logout {
    [[QYSDK sharedSDK] logout:^(BOOL success) {}];
}

- (void)show {
    QYSource *source = [[QYSource alloc] init];
    source.title =  @"在线客服";
    source.urlString = @"https://8.163.com/";
    
    QYSessionViewController *sessionViewController = [[QYSDK sharedSDK] sessionViewController];
    sessionViewController.sessionTitle = @"在线客服";
    sessionViewController.source = source;
    sessionViewController.groupId = 0;
    sessionViewController.staffId = 0;
    sessionViewController.commonQuestionTemplateId = 0;
    sessionViewController.openRobotInShuntMode = YES;
    
    UIBarButtonItem *leftItem = [[UIBarButtonItem alloc] initWithTitle:@"返回" style:UIBarButtonItemStylePlain target:self action:@selector(_onBack:)];
    sessionViewController.navigationItem.leftBarButtonItem = leftItem;
    
    UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:sessionViewController];
    [UIApplication.sharedApplication.delegate.window.rootViewController presentViewController:nav animated:YES completion:^{
    }];
}

- (void)_onBack:(id)sender {
    [UIApplication.sharedApplication.delegate.window.rootViewController dismissViewControllerAnimated:YES completion:nil];
}
@end
